pub struct Client { /* private fields */ }Expand description
A Client is a simple client which sends a request and returns a response.
The connection timing, e.g. TCP/TLS overhead, will be inserted into the response if it exits.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn new_connection(self, conn_type: ConnectionType) -> Self
pub fn new_connection(self, conn_type: ConnectionType) -> Self
Create a new connection for each request.
Sourcepub fn headers(self, headers: HeaderMap<HeaderValue>) -> Self
pub fn headers(self, headers: HeaderMap<HeaderValue>) -> Self
Set the headers for the upload or download request.
Sourcepub fn scoped_headers(self, scoped_headers: Option<ScopedHeaders>) -> Self
pub fn scoped_headers(self, scoped_headers: Option<ScopedHeaders>) -> Self
Set headers that are only attached when the request’s host matches the
scope’s allowlist. Headers set via Self::headers take precedence.