ConnectionTiming

Struct ConnectionTiming 

pub struct ConnectionTiming { /* private fields */ }
Timing stats for the establishment of a connection. All durations are calculated from the start of the connection.

Implementations

Source

impl ConnectionTiming

pub fn new(start: Timestamp) -> Self

Creates a new ConnectionTiming.

pub fn set_lookup(&mut self, at: Timestamp)

Set the time it took to perform DNS resolution of the peer’s host.

pub fn set_connect(&mut self, at: Timestamp)

Set the time it took to create the connection with the remote peer.

pub fn set_secure(&mut self, at: Timestamp)

Set the time it took to secure a connection.

pub fn set_application(&mut self, at: Timestamp)

Set the time it took to setup the L7 protocol, H1/2/3.

pub fn start(&self) -> Timestamp

Returns when the connection started.

pub fn time_lookup(&self) -> Duration

Returns how long it took for DNS to resolve.

pub fn time_connect(&self) -> Duration

Returns how long it took for the transport to connect.

pub fn set_dns_lookup(&mut self, duration: Duration)

Set the duration of the DNS lookup

pub fn dns_time(&self) -> Duration

Returns the DNS lookup duration.

pub fn time_secure(&self) -> Duration

Returns how long it took for the security handshake to complete.

pub fn time_application(&self) -> Duration

Returns how long it took for the H/{1,2,3} handshake to complete.

pub fn set_tls_round_trips(&mut self, round_trips: u32)

Sets the number of round-trips the TLS handshake took.

pub fn tls_round_trips(&self) -> u32

Returns the number of round-trips the TLS handshake took (>= 1).

pub fn tcp_handshake(&self) -> Duration

The duration of the TCP handshake alone (excluding DNS resolution), i.e. tcp_f in draft-ietf-ippm-responsiveness-09 5.3.

This is the interval between the transport starting to connect and the connection being established. When the connection timing starts after DNS resolution (as it does for the responsiveness probes), time_lookup is zero and this is simply time_connect.

pub fn tls_handshake(&self) -> Duration

The duration of the TLS handshake alone (excluding the preceding TCP handshake), i.e. the un-normalized tls_f in draft-ietf-ippm-responsiveness-09 5.3.

For QUIC/H3 connections time_secure is zero (TLS is folded into the transport handshake), so this saturates to zero rather than underflowing. Divide by Self::tls_round_trips to obtain the normalized value.