pub struct LoadGenerator { /* private fields */ }Implementations
Sourceimpl LoadGenerator
impl LoadGenerator
pub fn new(config: LoadConfig) -> Result<Self>
pub fn new_loaded_connection( &self, direction: Direction, conn_type: ConnectionType, network: Arc<dyn Network>, time: Arc<dyn Time>, shutdown: CancellationToken, ) -> Result<OneshotResult<LoadedConnection>>
pub fn connections(&self) -> impl Iterator<Item = &LoadedConnection>
pub fn random_connection(&self) -> Option<Arc<RwLock<EstablishedConnection>>>
pub fn push(&mut self, loaded_connection: LoadedConnection)
pub fn update(&mut self)
Sourcepub fn ongoing_loads(&self) -> impl Iterator<Item = &LoadedConnection>
pub fn ongoing_loads(&self) -> impl Iterator<Item = &LoadedConnection>
Connections still transferring: neither completed nor terminated early.
Excluding failed connections is what lets the ramp replace them and keeps self probes off dead connections.
pub fn count_loads(&self) -> usize
Sourcepub fn count_failed_loads(&self) -> usize
pub fn count_failed_loads(&self) -> usize
Number of load-generating connections that terminated early with an error.
pub fn into_connections(self) -> Vec<LoadedConnection>